#ifndef NT2_INCLUDE_CONSTANTS_MEIGHT_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MEIGHT_HPP_INCLUDED

#include <nt2/constant/include/constants/meight.hpp>

#endif
